:orphan:

.. _whats_new:

********************************
What's New in Cosmo-Utils v0.1.0
********************************

`Cosmo-Utils` ``v.0.1.0`` is now availble for installation with pip.
See :ref:`changelog` for details on smaller issues and bug-fixes.

See :ref:`whats_new_v0x_history` for full release history information.
